---
title: <span class="badge builder"></span> TimeIntervalTimeRange
---
# <span class="badge builder"></span> TimeIntervalTimeRange

## Constructor

```python
TimeIntervalTimeRange()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> alerting.TimeIntervalTimeRange
```

### <span class="badge object-method"></span> end_time

```python
def end_time(end_time: str) -> typing.Self
```

### <span class="badge object-method"></span> start_time

```python
def start_time(start_time: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [TimeIntervalTimeRange](./object-TimeIntervalTimeRange.md)
